#
# spec file for package tiny
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tiny
Version:        0.13.0+git5.g2ee969a
Release:        2.1
Summary:        Terminal IRC client written in Rust
License:        (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR ISC OR MIT) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Apache-2.0 OR MIT OR BSD-2-Clause) AND (MIT OR Unlicense) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND CC0-1.0 AND ISC AND MIT AND MIT
URL:            https://github.com/osa1/tiny
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  zstd
BuildRequires:  pkgconfig(dbus-1)

%description
A terminal IRC client written in Rust.

%prep
%autosetup -a1

%build
%{cargo_build} --features desktop-notifications

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/tiny %{buildroot}%{_bindir}/tiny

%check
%{cargo_test} --workspace --exclude '*termbox*'

%files
%license LICENSE
%doc     README.md CHANGELOG.md
%{_bindir}/tiny

%changelog
* Fri Jun 13 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Do not require pkgconfig(dbus-1) and pkgconfig(openssl): those
  are devel packages and not needed at runtime.
* Sun Jun  1 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 0.13.0+git5.g2ee969a:
  * Update dependencies
  * Added support for `ctrl_h` and `ctrl_i` in keymap config (#444)
  * Untangles the keystrokes ctrl-h and backspace (#445)
  * Auto-fix some recent lints
  * Update tiny version in Cargo.lock
* Sun Apr  6 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 0.13.0+git2:
  * Auto-fix some recent lints
  * Update tiny version in Cargo.lock
  * Release v0.13.0
  * Use IndexMap in byte_seq_parser macro (#438)
  * Improve handling of IRC color code (0x03) without colors afterwards (#435)
  * Fix default-features deprecation warning
- skip testing termbox examples due to compilation issues
* Thu Oct 31 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Fix build finding dbus-1.pc by installing dbus-1-devel
* Sun Oct 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 0.12.0+git15:
  * Fix rustls deprecation warning
  * Refactor termbox attribute values and make it clear that they can be manipulated w bit sets
  * Remove msg_area::Line::force_recalculation
  * Fix a warning, new lints
  * Upgrade ring to 0.17
  * Fix assigning_clones lints
  * Improve matching when highligting mentions
  * Use dbus instead of zbus for desktop notifications
  * Remove `WidgetRet::Quit` and `TUIRet::Quit`:
  * Some renaming in TUI for consistency, documentation
  * Refactor TUI event type:
  * Remove a redundant `pub`
  * Update tokio
- Use recomprizz instead of recompress in _service
* Tue Mar 26 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.12.0+git2:
  * Update tokio, serde, fix a new lint (1.76.0) and a warning in test
- Remove cargo_config to adopt new vendored tarball scheme.
* Mon Jan  1 2024 Michael Vetter <mvetter@suse.com>
- Update to version 0.12.0:
  New features:
  * New TUI text attributes italic and strikethrough added to the
    config file parser. These can be combined with the existing
    bold and underline attributes. (#409, #404)
  * Added support for key bindings that run commands. Example:
    key_map:
    ctrl_d:
    command: quit (#403, #410)
  Bug fixes and other improvements:
  * Default config updated with better comments, color config
    for join/part messages. (#412)
  * /join command errors now print usage help once instead of
    twice. (c512887)
  * Fix showing timestamp of the next message or activity
    after a /clear. (#417)
  * Fix a crash when the config file is deleted before
    a /reload. (3ea5678)
* Wed Sep 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix and update vendored tarball
- Remove leftover obscpio file
* Tue Sep  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored sources.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sat Aug  5 2023 socvirnyl.estela@gmail.com
- Update to version 0.11.0+git7:
  * Bug fixes and refactoring in key map implementation:
  * Update CHANGELOG, initial config
  * Rename 'run_command' key action to just 'command'
  * Support tiny commands in keymap config (#410)
  * Support italic and strikethrough attribute (#404) (#409)
  * Fix tab config test with desktop-notifications feature (#408)
  * Update deps, reword and format initial config, fix new lints
  * Update changelog
  * Update dependencies (#405)
  * Config to set /ignore and /notify (#344)
  * CHANGELOG: Add #403
  * Implement bold, italic, underline, strikethrough rendering
  * Added support for SASL EXTERNAL  (#363)
  * Fix a few lints introduced with rustc 1.66.0
  * CHANGELOG: Remove trailing ws, formatting
  * Implement running shell commands for getting passwords (#315)
  * Fix a bug when running $EDITOR on macOS 12
  * Mention default macOS config path in README
  * Update CHANGELOG with #395
  * Allow QUIT and PART with a message (#395)
* Fri Jun  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies.
- Enable desktop notification feature.
* Mon Dec  5 2022 socvirnyl.estela@gmail.com
- Update to version 0.10.0+git14:
  * Fix new lints and warnings (#394)
- Automatic update of vendored dependencies.
* Fri Nov  4 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Automatic update of vendored dependencies.
* Mon Aug 29 2022 socvirnyl.estela@gmail.com
- Update of vendored dependencies
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Wed Jun  1 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix versioning format.
- Update to version 0.10.0+git13 (mostly dependency update and some fixes):
  * Update dependencies (#386)
  * Move to 2021 edition (#385)
  * Fix clippy warnings (#383)
  * Remove alias field in `Tab`, store visible name, remove `MsgSource::visible_name`
  * Suppress some clippy warnings
  * Document ERR_NICKNAMEINUSE handling in conn handler, remove a TODO
  * Fix potential UB in `term_input::read_stdin`
  * Bump dependencies
  * Update messages in some of the tests to avoid confusion
  * Bump deps
  * Fix handling of CR, LR, tabs in IRC format parser
  * Fix a few doc warnings
  * Bump deps
* Wed Jun  1 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Automatic update of vendored dependencies
- Fix some build errors
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue Mar 15 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for tiny (0.10.0)
